@echo off
REM Install Google Chrome
REM ----------------------------------------------------------

set LOGFILE=c:\ocs\%date:~10,4%_%date:~4,2%_%date:~7,2%_ocs.log
set MSILOG=c:\ocs\%date:~10,4%_%date:~4,2%_%date:~7,2%_chrome.log
set PWDIR=%~dp0
set MSICMD=
set REGCMD=
set QUIET=NO
set PKGNM=Google Chrome 64-bit

mkdir c:\ocs > nul 2>&1

echo =========  Start install %PKGNM%  %date% - %time% ============= >> %LOGFILE%

REM ====================================================================
REM  check for any command line options
REM  use the /q option when run via OCS to put in quiet mode
REM ====================================================================
    set arg=%1
    if "%arg%" == "-q" (
       set QUIET=YES
    )
echo [[ %DATE% %TIME% ]] Quiet option defined >> %LOGFILE%
REM ====================================================================
REM Check if I am on a 64-bit machine or not.  On the 64-bit machines,
REM OCS runs in a 32-bit command prompt.  But I need the installer to 
REM via the 64-bit command prompt.
REM ====================================================================
if exist %WINDIR%\sysnative\cmd.exe (
	REM I am on a 64bit machine, running the 32bit command prompt
	set MSICMD=%WINDIR%\sysnative\msiexec.exe
	set REGCMD=%WINDIR%\sysnative\reg.exe
) ELSE (
	REM I must be on a 32bit machine, or already running at the 64bit
	REM command prompt
	set MSICMD=msiexec.exe
	set REGCMD=%WINDIR%\System32\reg.exe
)
echo [[ %DATE% %TIME% ]] 32bit/64bit option defined >> %LOGFILE%

REM ====================================================================
REM    Copy School Bookmarks
REM ====================================================================
copy /y %PWDIR%\bookmarks.html c:\pavcs\bookmarks.html >> %LOGFILE% 2>&1

if %ERRORLEVEL% GEQ 1 (goto :failpre)

if not %QUIET% == YES echo Bookmarks copied over ...

REM ====================================================================
REM    Install Chrome
REM ====================================================================

echo [[ %DATE% %TIME% ]] Running Chrome Installers....... >> %LOGFILE%
if exist "%MSILOG%" (
	del "%MSILOG%" >> %LOGFILE% 2>&1
	)

cmd.exe /S /C "start /wait %MSICMD% /i %PWDIR%\googlechromestandaloneenterprise64.msi /qn /norestart /L*v "%MSILOG%" " >> %LOGFILE% 2>&1

REM Because of the cmd always completing, there is no valid exit codes.
REM only way to see if install was successful is to check the %MSILOG%
REM file, and search for string

find /C /I "Product: Google Chrome -- Installation completed successfully" "%MSILOG%" >> %LOGFILE%

if %ERRORLEVEL% GEQ 1 (goto :failinstall)

if not %QUIET% == YES echo Completed installer ...

REM ====================================================================
REM    Turn off Auto-Update at registry
REM ====================================================================

echo [[ %DATE% %TIME% ]] Updating registry....... >> %LOGFILE%

%REGCMD% add "HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Google\Update" /v UpdateDefault /t REG_DWORD /d 00000000 /f >> %LOGFILE% 2>&1

if %ERRORLEVEL% GEQ 1 (goto :failpost)

if not %QUIET% == YES echo Updated Registry...

REM ====================================================================
REM   Copy over the master preferences file
REM ====================================================================

echo [[ %DATE% %TIME% ]] Copying master preferences file....... >> %LOGFILE%

copy /y %PWDIR%\master_preferences "%PROGRAMFILES%\Google\Chrome\Application\master_preferences" >> %LOGFILE% 2>&1

if %ERRORLEVEL% GEQ 1 (goto :failpost)

if not %QUIET% == YES echo Master preference file copyied...

goto :endgood

REM ==============================================================

REM Something went really wrong if I get to this point
goto :endbad

REM ==============================================================
:failpre
	echo [[ %DATE% %TIME% ]] Error occurred before install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  4
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 4


REM ==============================================================
:failpost
	echo [[ %DATE% %TIME% ]] Error occurred after install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  6
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 6

REM ==============================================================
:failinstall
	echo [[ %DATE% %TIME% ]] Error occurred during install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  8
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 8

REM ==============================================================
:endbad
	echo [[ %DATE% %TIME% ]] Something went horribly wrong >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  100
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 100

REM ==============================================================
:endgood
	echo [[ %DATE% %TIME% ]] %PKGNM% completed with no errors reported >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE: 0
		echo DATE:  %DATE% %TIME%
		echo Package has completed successfully.
		echo Press any key to close window
		pause > nul
	)
	exit








